@@ -2,7 +2,7 @@
 """Contains the DataSource class.
 
 @author: Donald Erb
-Created on Fri Jul 31 16:22:51 2020
+Created on Jul 31, 2020
 
 #TODO need to update all docstrings
 """
@@ -14,7 +14,7 @@ import numpy as np
 from openpyxl.styles import Alignment, Border, Font, PatternFill, Side
 import pandas as pd
 
-from .utils import optimize_memory, DEFAULT_FITTING_FORMATS
+from . import utils
 from .functions import SeparationFunction, CalculationFunction, SummaryFunction
 
 
@@ -56,8 +56,7 @@ class DataSource:
             excel_column_offset=0,
             entry_separation=0,
             sample_separation=0,
-            label_entries=True
-        ):
+            label_entries=True):
         """
         DataSource initialization.
 
@@ -114,7 +113,8 @@ class DataSource:
         Raises
         ------
         ValueError
-            Raised if the input name is a blank string.
+            Raised if the input name is a blank string, or if either excel_row_offset
+            or excel_column_offset is < 0.
         TypeError
             DESCRIPTION.
         IndexError
@@ -138,8 +138,6 @@ class DataSource:
         self.num_files = num_files
         self.sample_separation = sample_separation
         self.entry_separation = entry_separation
-        self.excel_row_offset = excel_row_offset
-        self.excel_column_offset = excel_column_offset
         self.label_entries = label_entries
         self.column_labels = column_labels if column_labels is not None else []
         self.figure_rcParams = figure_rcParams if figure_rcParams is not None else {}
@@ -150,6 +148,13 @@ class DataSource:
                 separator = separator.replace(*replacement)
         self.separator = separator
 
+        # Ensures excel_row_offset and excel_column_offset are >= 0
+        if any(value < 0 for value in (excel_column_offset, excel_row_offset)):
+            raise ValueError('excel_column_offset and excel_row_offset must be >= 0.')
+        else:
+            self.excel_row_offset = excel_row_offset
+            self.excel_column_offset = excel_column_offset
+
         if unique_variables is None:
             self.unique_variables = []
         elif isinstance(unique_variables, str):
@@ -160,12 +165,12 @@ class DataSource:
         if column_numbers is not None:
             self.column_numbers = column_numbers
         else:
-            self.column_numbers = [*range(len(self.unique_variables))]
+            self.column_numbers = list(range(len(self.unique_variables)))
 
         # ensures the number of imported columns can accomodate all variables
         if len(self.column_numbers) < len(self.unique_variables):
             raise IndexError((
-                f'The number of columns specified for DataSouce "{self.name}" must \n'
+                f'The number of columns specified for mcetl.DataSource "{self.name}" must '
                 'be greater or equal to the number of unique variables, not less than.'
             ))
 
@@ -194,7 +199,7 @@ class DataSource:
 
         # indices for each unique variable for data processing
         if unique_variable_indices is None:
-            self.unique_variable_indices = [*range(len(self.unique_variables))]
+            self.unique_variable_indices = list(range(len(self.unique_variables)))
         elif isinstance(unique_variable_indices, (str, int)):
             self.unique_variable_indices = [unique_variable_indices]
         else:
@@ -216,7 +221,7 @@ class DataSource:
 
 
     def __str__(self):
-        return f'mcetl.{self.__class__.__name__} {self.name}'
+        return f'{self.__module__}.{self.__class__.__name__} {self.name}'
 
 
     def __repr__(self):
@@ -289,7 +294,7 @@ class DataSource:
                 'alignment': Alignment(horizontal='center', vertical='center'),
                 'number_format': '0.00',
             },
-            **DEFAULT_FITTING_FORMATS
+            **utils.DEFAULT_FITTING_FORMATS
         }
 
         if format_kwargs is not None:
@@ -319,27 +324,27 @@ class DataSource:
                          + self.dataset_summary_functions):
             # ensure function names are unique
             if function.name in unique_keys:
-                raise ValueError(
-                    f'The name "{function.name}" is associated with two different '\
+                raise ValueError((
+                    f'The name "{function.name}" is associated with two different '
                     f'Function objects in the DataSource "{self.name}", which is not allowed.'
-                )
+                ))
             # ensure targets exist
             for target in function.target_columns:
                 if target not in unique_keys:
-                    raise ValueError(
-                        f'"{target}" is not an available target for Function '\
+                    raise ValueError((
+                        f'"{target}" is not an available target for Function '
                         f'"{function.name}". Check that the function order is correct.'
-                    )
+                    ))
             # ensure columns exist if function modifies columns
             if (not isinstance(function, SeparationFunction)
                     and not isinstance(function.added_columns, int)):
 
                 for target in function.added_columns:
                     if target not in unique_keys:
-                        raise ValueError(
+                        raise ValueError((
                             f'"{target}" is not an available column for Function '\
                             f'"{function.name}" to modify. Check that the function order is correct.'
-                        )
+                        ))
             # ensure summary functions either add columns or modify other summary columns
             if (isinstance(function, SummaryFunction)
                     and not isinstance(function.added_columns, int)):
@@ -350,10 +355,10 @@ class DataSource:
                     sum_funcs = [function.name for function in self.dataset_summary_functions]
 
                 if any(column not in sum_funcs for column in function.added_columns):
-                    raise ValueError(
-                        f'Error with "{function.name}". SummaryFunctions can only modify '\
+                    raise ValueError((
+                        f'Error with "{function.name}". SummaryFunctions can only modify '
                         'other SummaryFunction columns.'
-                    )
+                    ))
 
             unique_keys.append(function.name)
 
@@ -372,7 +377,7 @@ class DataSource:
                 for function in self.calculation_functions:
                     if isinstance(function.added_columns, int):
                         end_index = start_index + function.added_columns
-                        reference[function.name] = [*range(start_index, end_index)]
+                        reference[function.name] = list(range(start_index, end_index))
 
                         for num in range(start_index, end_index):
                             dataframe[num] = pd.Series(np.nan, dtype=np.float32)
@@ -401,9 +406,9 @@ class DataSource:
                 for function in self.sample_summary_functions:
                     if isinstance(function.added_columns, int):
                         end_index = start_index + function.added_columns
-                        references[i][-1][function.name] = [
-                            *range(start_index, end_index)
-                        ]
+                        references[i][-1][function.name] = list(
+                            range(start_index, end_index)
+                        )
                         for num in range(start_index, end_index):
                             data[num] = np.nan
                         start_index = end_index
@@ -424,9 +429,9 @@ class DataSource:
             for function in self.dataset_summary_functions:
                 if isinstance(function.added_columns, int):
                     end_index = start_index + function.added_columns
-                    references[-1][-1][function.name] = [
-                        *range(start_index, end_index)
-                    ]
+                    references[-1][-1][function.name] = list(
+                        range(start_index, end_index)
+                    )
                     for num in range(start_index, end_index):
                         data[num] = np.nan
                     start_index = end_index
@@ -586,7 +591,7 @@ class DataSource:
                     (entry for entry in sample), axis=1) for sample in dataset),
                 axis=1
             )
-            dataset_dataframe.columns = [*range(len(dataset_dataframe.columns))]
+            dataset_dataframe.columns = list(range(len(dataset_dataframe.columns)))
             merged_dataframes.append(dataset_dataframe)
 
         self.lengths = lengths
@@ -611,6 +616,11 @@ class DataSource:
         processed_dataframes : list
             The list of dataframes after processing.
 
+        Notes
+        -----
+        The start row is set to self.excel_row_offset + 3 since openpyxl is 1-based
+        and there are two header rows.
+
         """
 
         functions = (self.calculation_functions + self.sample_summary_functions
@@ -621,11 +631,11 @@ class DataSource:
             for function in functions:
                 dataset = function.do_function(
                     dataset, self.references[i], index,
-                    self.excel_column_offset, self.excel_row_offset
+                    self.excel_column_offset, self.excel_row_offset + 3
                 )
 
             # Optimizes memory usage after calculations
-            processed_dataframes.append(optimize_memory(dataset, bool(index)))
+            processed_dataframes.append(utils.optimize_memory(dataset, bool(index)))
 
         return processed_dataframes
 
@@ -666,6 +676,7 @@ class DataSource:
         -------
         list
             The list of dataframes after processing.
+
         """
 
         return self._do_functions(dataframes, 1)
@@ -795,7 +806,7 @@ class DataSource:
         """
 
         labels = self.create_needed_labels()
-        label_template = [*itertools.chain(*labels)]
+        label_template = list(itertools.chain.from_iterable(labels))
 
         print((
             f'\nImported data labels: {len(labels[0])}\n'
