@@ -4,7 +4,7 @@
 #TODO add an option to select each file individually
 
 @author: Donald Erb
-Created on Mon Sep  2 22:08:12 2019
+Created on Sep 2, 2019
 
 """
 
@@ -20,18 +20,6 @@ from .utils import safely_close_window, validate_inputs, PROCEED_COLOR
 
 __all__ = ['file_finder', 'file_mover']
 
-_HELP_TEXT = (
-    'For example, consider the following files:\n\n'
-    '    Ti-10Ni-700, Ti-20Ni-700, Ti-10Ni-800, Ti-20Ni-800,\n'
-    '    Ti-10Fe-700, Ti-20Fe-700, Ti-10Fe-800, Ti-20Fe-800,\n'
-    '    Co-10Ni-700, Co-20Ni-700, Co-10Ni-800, Co-20Ni-800,\n'
-    '    Co-10Fe-700, Co-20Fe-700, Co-10Fe-800, Co-20Fe-800\n\n'
-    'If only the files for the 700 samples were wanted, then one possible search could be \n'
-    'two main keywords ("Ti, 700" and "Co, 700") and four secondary \n'
-    'keywords ("10Ni", "20Ni", "10Fe", "20Fe").\n\nLeave all entries blank to find all '
-    'files with the given file extension under the specified folder.\n'
-)
-
 
 def _prepare_for_search(input_str):
     """
@@ -44,7 +32,7 @@ def _prepare_for_search(input_str):
 
     Returns
     -------
-    output_str : str
+    str
         The input string containing no consecutive stars ('*').
 
     """
@@ -53,14 +41,12 @@ def _prepare_for_search(input_str):
     output_list.extend(
         [letter for i, letter in enumerate(input_str[1:]) if letter != '*' or input_str[i] != '*']
     )
-    output_str = ''.join(output_list)
 
-    return output_str
+    return ''.join(output_list)
 
 
-def _generate_num_keyword_window(
-        file_directory=None, keyword_1=None, keyword_2=None, file_type=None,
-        num_files=None, previous_inputs=None, location=(None, None)):
+def _generate_num_keyword_window(file_directory=None, file_type=None, num_files=None,
+                                 previous_inputs=None, location=(None, None)):
     """
     Creates a Window to select the number of keywords and other file search parameters.
 
@@ -68,10 +54,6 @@ def _generate_num_keyword_window(
     ----------
     file_directory : str
         String for the topmost folder under which all files are searched.
-    keyword_1 : str, tuple, or list
-        String or list of strings for the main keyword.
-    keyword_2 : str, tuple, or list
-        String or list of strings for the secondary keyword.
     file_type : str
         The file extension that is being searched, eg. csv, txt, pdf.
     num_files: int
@@ -91,16 +73,16 @@ def _generate_num_keyword_window(
     """
 
     default_inputs = {
-        'num_keyword_1': len(keyword_1) if keyword_1 is not None else '',
-        'num_keyword_2': len(keyword_2) if keyword_2 is not None else '',
+        'num_datasets': '',
         'file_type': file_type.replace('.', '') if file_type is not None else '',
-        'num_files': num_files if num_files is not None else 1,
+        'min_files': num_files if num_files is not None else 1,
+        'max_files': num_files if num_files is not None else 1,
         'folder' : file_directory if file_directory is not None else '',
         'folder_initial': file_directory
     }
 
-    previous_inputs = previous_inputs if previous_inputs is not None else {}
-    default_inputs.update(previous_inputs)
+    if previous_inputs is not None:
+        default_inputs.update(previous_inputs)
 
     layout = [
         [sg.Text('Choose the topmost folder for searching:', size=(35, 1))],
@@ -108,20 +90,19 @@ def _generate_num_keyword_window(
                   size=(26, 1)),
          sg.FolderBrowse(key='search', target='folder',
                          initial_folder=default_inputs['folder_initial'])],
-        [sg.Text('')],
-        [sg.Text('Number of main keywords:', size=(28, 1)),
-         sg.Input(key='num_keyword_1', do_not_clear=True, size=(5, 1), focus=True,
-                  default_text=default_inputs['num_keyword_1'])],
-        [sg.Text('Number of secondary keywords:', size=(28, 1)),
-         sg.Input(key='num_keyword_2', do_not_clear=True, size=(5, 1),
-                  default_text=default_inputs['num_keyword_2'])],
-        [sg.Text('')],
+        [sg.Text('Number of datasets:', size=(28, 1)),
+         sg.Input(key='num_datasets', do_not_clear=True, size=(5, 1), focus=True,
+                  default_text=default_inputs['num_datasets'])],
         [sg.Text('File extension (eg. csv or txt):', size=(28, 1)),
          sg.Input(key='file_type', do_not_clear=True, size=(5, 1),
                   default_text=default_inputs['file_type'])],
-        [sg.Text('Maximum number of files\nper search term:', size=(28, 2)),
-         sg.Input(key='num_files', do_not_clear=True, size=(5, 1),
-                  default_text=default_inputs['num_files'])],
+        [sg.Text('Number of files per search term:')],
+        [sg.Text('    Minimum:', size=(14, 1)),
+         sg.Input(key='min_files', do_not_clear=True, size=(5, 1),
+                  default_text=default_inputs['min_files'])],
+        [sg.Text('    Maximum:', size=(14, 1)),
+         sg.Input(key='max_files', do_not_clear=True, size=(5, 1),
+                  default_text=default_inputs['max_files'])],
         [sg.Text('')],
         [sg.Button('Help'),
          sg.Button('Next', bind_return_key=True, button_color=PROCEED_COLOR)]
@@ -130,9 +111,8 @@ def _generate_num_keyword_window(
     return sg.Window('Search Criteria', layout, location=location)
 
 
-def _get_num_keywords(
-        file_directory=None, keyword_1=None, keyword_2=None, file_type=None,
-        num_files=None, previous_inputs=None, location=(None, None)):
+def _get_num_keywords(file_directory=None, file_type=None, num_files=None,
+                      previous_inputs=None, location=(None, None)):
     """
     Launches a GUI to get the number of keywords and other file search parameters.
 
@@ -140,10 +120,6 @@ def _get_num_keywords(
     ----------
     file_directory : str
         String for the topmost folder under which all files are searched.
-    keyword_1 : str, tuple, or list
-        String or list of strings for the main keyword.
-    keyword_2 : str, tuple, or list
-        String or list of strings for the secondary keyword.
     file_type : str
         The file extension that is being searched, eg. csv, txt, pdf.
     num_files: int
@@ -156,22 +132,13 @@ def _get_num_keywords(
 
     Returns
     -------
-    file_directory : Path
-        The Path for the topmost folder for searching.
-    num_keyword_1 : int
-        The number of keywords for keyword_1.
-    num_keyword_2 : int
-        The number of keywords for keyword_2.
-    file_type : str
-        The file extension to search for.
     values : dict
         The values needed to regenerate the layout with the final selected fields.
 
     """
 
     window = _generate_num_keyword_window(
-        file_directory, keyword_1, keyword_2, file_type,
-        num_files, previous_inputs, location
+        file_directory, file_type, num_files, previous_inputs, location
     )
 
     validations = {
@@ -180,9 +147,9 @@ def _get_num_keywords(
             ['file_type', 'file extension']
         ],
         'integers': [
-            ['num_keyword_1', 'number of main keywords'],
-            ['num_keyword_2', 'number of secondary keywords'],
-            ['num_files', 'maximum number of files per search term']
+            ['num_datasets', 'number of datasets'],
+            ['min_files', 'mininum number of files per search term'],
+            ['max_files', 'maximum number of files per search term']
         ]
     }
 
@@ -193,44 +160,41 @@ def _get_num_keywords(
             safely_close_window(window)
 
         elif event == 'Help':
-            sg.popup(_HELP_TEXT, title='Help')
+            sg.popup(
+                ('All folders and files under the topmost folder will be searched.\n\n'
+                 'The number of datasets is equal to the number of sheets '
+                 'to create in Excel, if writing to Excel.\n'),
+                title='Help')
 
         elif event == 'Next':
             if validate_inputs(values, **validations):
-                if int(values['num_keyword_1']) > 0 and int(values['num_keyword_2']) > 0:
-                    if int(values['num_files']) > 0:
-                        break
-                    else:
-                        sg.popup('Maximum number of files must be > 0.\n',
-                                 title='Error')
+                if int(values['num_datasets']) <= 0:
+                    sg.popup('Number of datasets must be > 0.\n', title='Error')
+                elif int(values['min_files']) <= 0 or int(values['max_files']) <= 0:
+                    sg.popup('Number of files per search term must be > 0.\n',
+                             title='Error')
+                elif int(values['min_files']) > int(values['max_files']):
+                    sg.popup(
+                        'Minimum files must be less than or equal to maximum files.\n',
+                        title='Error'
+                    )
                 else:
-                    sg.popup('Number of keywords must be > 0.\n', title='Error')
+                    break
 
     window.close()
     del window
 
-    num_keyword_1 = int(values['num_keyword_1'])
-    num_keyword_2 = int(values['num_keyword_2'])
-
-    return num_keyword_1, num_keyword_2, values
+    return values
 
 
-def _generate_keyword_window(
-        num_keyword_1, num_keyword_2, keyword_1=None, keyword_2=None,
-        previous_inputs=None, location=(None, None)):
+def _generate_keyword_window(num_datasets, previous_inputs=None, location=(None, None)):
     """
     Creates a Window to enter the terms for each keyword.
 
     Parameters
     ----------
-    num_keyword_1 : int
-        The number of keywords for keyword_1.
-    num_keyword_2 : int
-        The number of keywords for keyword_2.
-    keyword_1 : tuple or list
-        Tuple or list of strings for the main keyword.
-    keyword_2 : tuple or list
-        Tuple or list of strings for the secondary keyword.
+    num_datasets : int
+        The number of datasets.
     previous_inputs : dict
         A dictionary containing the values from a previous run of this function,
         used to regenerate the layout.
@@ -244,55 +208,32 @@ def _generate_keyword_window(
 
     """
 
-    # default values for keywords
-    if keyword_1 is None:
-        if num_keyword_1 == 0:
-            default_keyword_1 = ['']
-        else:
-            default_keyword_1 = [''] * num_keyword_1
-    else:
-        default_keyword_1 = [keyword for keyword in keyword_1]
-        # in case num_keyword_1 is greater than the number of user inputs for keyword 1
-        default_keyword_1.extend(['' for i in range(num_keyword_1 - len(keyword_1))])
+    default_inputs = {f'shared_keyword_{i}': '' for i in range(num_datasets)}
+    default_inputs.update({f'unique_keyword_{i}': '' for i in range(num_datasets)})
 
-    if keyword_2 is None:
-        if num_keyword_2 == 0:
-            default_keyword_2 = ['']
-        else:
-            default_keyword_2 = [''] * num_keyword_2
-    else:
-        default_keyword_2 = [keyword for keyword in keyword_2]
-        default_keyword_2.extend(
-            ['' for i in range(num_keyword_2 - len(keyword_2))]
-        )
+    if previous_inputs is not None:
+        default_inputs.update(previous_inputs)
 
-    default_options = {f'keyword_1_{i}': kw for i, kw in enumerate(default_keyword_1)}
-    default_options.update({
-        f'keyword_2_{i}': kw for i, kw in enumerate(default_keyword_2)
-    })
-
-    previous_inputs = previous_inputs if previous_inputs is not None else {}
-    default_inputs = dict(default_options, **previous_inputs)
-
-    keyword_1_inputs = [
-        [sg.Text(f'    entry {i+1}'),
-         sg.Input(default_inputs[f'keyword_1_{i}'], key=f'keyword_1_{i}',
-                  do_not_clear=True, size=(20, 1))]
-        for i in range(num_keyword_1)]
-    keyword_2_inputs = [
-        [sg.Text(f'    entry {i+1}'),
-         sg.Input(default_inputs[f'keyword_2_{i}'], key=f'keyword_2_{i}',
-                  do_not_clear=True, size=(20, 1))]
-        for i in range(num_keyword_2)]
+    dataset_inputs = []
+    for i in range(num_datasets):
+        dataset_inputs.extend([
+            [sg.Text(f'Dataset {i+1} (search terms:'),
+             sg.Text(f'{len(default_inputs[f"unique_keyword_{i}"].split(";"))})',
+                     key=f'num_terms_{i}')],
+            [sg.Text('  Shared keyword(s):', size=(18, 1)),
+             sg.Input(default_inputs[f'shared_keyword_{i}'],
+                      key=f'shared_keyword_{i}', size=(20, 1))],
+            [sg.Text('  Unique keyword(s):', size=(18, 1)),
+             sg.Input(default_inputs[f'unique_keyword_{i}'], size=(20, 1),
+                      key=f'unique_keyword_{i}', enable_events=True)],
+            [sg.Text('')]
+        ])
 
     layout = [
-        [sg.Text(('Entries for main keywords, separated\nby commas if'
-                  ' using more than one term:'))],
-        *keyword_1_inputs,
-        [sg.Text(('\nEntries for secondary keywords, separated\nby'
-                  ' commas if using more than one term:'))],
-        *keyword_2_inputs,
-        [sg.Text("")],
+        [sg.Frame('Search Terms',
+                  [[sg.Column(dataset_inputs, scrollable=True,
+                              vertical_scroll_only=True)]])],
+        [sg.Text('')],
         [sg.Button('Back'),
          sg.Button('Help'),
          sg.Button('Submit', bind_return_key=True, button_color=PROCEED_COLOR)]
@@ -301,22 +242,13 @@ def _generate_keyword_window(
     return sg.Window('Keyword Selection', layout, location=location)
 
 
-def _get_keywords(
-        num_keyword_1, num_keyword_2, keyword_1=None,
-        keyword_2=None, num_kw_values=None):
-    """Launches the GUI to enter the terms for each keyword.
+def _get_keywords(num_keyword_values):
+    """
+    Launches the GUI to enter the terms for each keyword.
 
     Parameters
     ----------
-    num_keyword_1 : int
-        The number of keywords for keyword_1.
-    num_keyword_2 : int
-        The number of keywords for keyword_2.
-    keyword_1 : tuple or list
-        Tuple or list of strings for the main keyword.
-    keyword_2 : tuple or list
-        Tuple or list of strings for the secondary keyword.
-    num_kw_values : dict
+    num_keyword_values : dict
         A dictionary containing the values to recreate the layout for the
         number of keywords window through _generate_num_keyword_window.
 
@@ -335,9 +267,9 @@ def _get_keywords(
 
     """
 
-    window = _generate_keyword_window(num_keyword_1, num_keyword_2,
-                                      keyword_1, keyword_2)
     location = (None, None)
+    old_text = ''
+    window = _generate_keyword_window(int(num_keyword_values['num_datasets']))
     while True:
         event, values = window.read()
 
@@ -345,46 +277,76 @@ def _get_keywords(
             safely_close_window(window)
 
         elif event == 'Help':
-            sg.popup(_HELP_TEXT, title='Help')
+            sg.popup(
+                ('Shared keywords are repeated for each search term in a dataset, '
+                 'while unique keywords are used once.\n\n'
+                 'Separate terms within keywords using "," and separate each unique '
+                 'keyword using ";".\n\nFor example, consider the following files:\n\n'
+                 '    Ti-10Ni-700, Ti-20Ni-700, Ti-10Ni-800, Ti-20Ni-800,\n'
+                 '    Ti-10Fe-700, Ti-20Fe-700, Ti-10Fe-800, Ti-20Fe-800,\n'
+                 '    Co-10Ni-700, Co-20Ni-700, Co-10Ni-800, Co-20Ni-800,\n'
+                 '    Co-10Fe-700, Co-20Fe-700, Co-10Fe-800, Co-20Fe-800\n\n'
+                 'If only the files for the Ti-700 samples were wanted, then '
+                 'one possible search could be \n a shared keyword of "ti, 700"'
+                 ' and unique keywords "10, ni; 20, ni; 30, ni; 10, fe; 20, fe; 30, fe".\n\n'
+                 'The six resulting search terms would be:\n    "ti, 700, 10, ni", '
+                 '"ti, 700, 20, ni", "ti, 700, 30, ni", "ti, 700, 10, fe", "ti, 700, 20, fe", '
+                 '"ti, 700, 30, fe".\n\nLeave keyword(s) blank to find all '
+                 'files with the given file extension under the specified folder.\n'),
+                title='Help')
 
         elif event == 'Back':
             location = window.current_location()
             window.close()
             window = None
-            num_keyword_1, num_keyword_2, num_kw_values = _get_num_keywords(
-                previous_inputs=num_kw_values, location=location
+            num_keyword_values = _get_num_keywords(
+                previous_inputs=num_keyword_values, location=location
             )
             window = _generate_keyword_window(
-                num_keyword_1, num_keyword_2, keyword_1, keyword_2,
-                values, location
+                int(num_keyword_values['num_datasets']), values, location
             )
 
-        else:
+        elif 'unique_keyword' in event:
+            max_index = max(int(key.split('_')[-1]) for key in values if key.startswith('unique'))
+            if int(event.split('_')[-1]) == 0:
+                for i in range(1, max_index + 1):
+                    if values[f'unique_keyword_{i}'] == old_text:
+                        window[f'unique_keyword_{i}'].update(values[event])
+                old_text = values[event]
+
+            for i in range(max_index + 1):
+                window[f'num_terms_{i}'].update(
+                    f"{len(window[f'unique_keyword_{i}'].get().split(';'))})"
+                )
+
+        elif event == 'Submit':
             break
 
     window.close()
     del window
 
-    kw_1_tmp = [values[f'keyword_1_{i}'].split(',') for i in range(num_keyword_1)]
-    kw_2_tmp = [values[f'keyword_2_{i}'].split(',') for i in range(num_keyword_2)]
-    # deletes repeated entries to reduce the permutations and search time
-    keyword_1 = [
-        set(entry.strip() for entry in kw_entries if entry) for kw_entries in kw_1_tmp
-    ]
-    keyword_2 = [
-        set(entry.strip() for entry in kw_entries if entry) for kw_entries in kw_2_tmp
-    ]
+    shared_keywords = []
+    unique_keywords = []
+    for i in range(int(num_keyword_values['num_datasets'])):
+        # deletes repeated entries to reduce the permutations and search time
+        shared_keywords.append(
+            set(entry.strip() for entry in values[f'shared_keyword_{i}'].split(',') if entry)
+        )
 
-    file_directory = Path(num_kw_values['folder'])
-    # in case the extension is given as something like .csv instead of csv
-    file_type = num_kw_values['file_type'].replace('.', '')
-    num_files = int(num_kw_values['num_files'])
+        kw_2_tmp = [entry.strip() for entry in values[f'unique_keyword_{i}'].split(';')]
+        unique_keywords.append([
+            set(entry.strip() for entry in entries.split(',') if entry) for entries in kw_2_tmp
+        ])
 
-    return file_directory, keyword_1, keyword_2, file_type, num_files
+    file_directory = Path(num_keyword_values['folder'])
+    file_type = num_keyword_values['file_type'].replace('.', '')
+    min_files = int(num_keyword_values['min_files'])
+    max_files = int(num_keyword_values['max_files'])
+
+    return file_directory, shared_keywords, unique_keywords, file_type, min_files, max_files
 
 
-def file_finder(file_directory=None, keyword_1=None, keyword_2=None,
-                file_type=None, num_files=None):
+def file_finder(file_directory=None, file_type=None, num_files=None):
     """
     Finds files that match the given keywords and file type using a GUI.
 
@@ -392,110 +354,86 @@ def file_finder(file_directory=None, keyword_1=None, keyword_2=None,
     ----------
     file_directory : str
         String for the topmost folder under which all files are searched.
-    keyword_1 : str, tuple, or list
-        String or list of strings for the main keyword.
-    keyword_2 : str, tuple, or list
-        String or list of strings for the secondary keyword.
     file_type : str
         The file extension that is being searched, eg. csv, txt, pdf.
     num_files : int
-        The maximum number of files to be associated with each search term.
+        The default maximum and minimum number of files to be associated with
+        each search term.
 
     Returns
     -------
     output_list : list
         A nested list of lists containing the file locations as strings
         for the files that matched the search term. len(output_list)
-        is equal to the number of main keywords (len(keyword_1)),
-        len(output_list[0]) is equal to the number of secondary keywords
-        (len(keyword_2)), and len(outupt_list[0][0]) is equal to the num_files.
-
-    Notes
-    -----
-    Leaving a blank string for all keywords will search for all files with
-    the given file extension under the parent folder.
-
-    If using more than one term for a keyword, input the terms together as
-    one string, separated by a comma. For example, if terms for keyword_1
-    are [['a', 'b'], ['c']], where ['a', 'b'] is one keyword and ['c'] is the other,
-    then input ['a, b', 'c'] for keyword_1.
+        is equal to the number of datasets, len(output_list[i]) is equal
+        to the number of unique keywords for dataset i, and len(outupt_list[i][j])
+        is equal to the number of files for dataset i and unique keyword j.
 
     """
 
-    # Ensures the keywords are input as lists
-    if keyword_1 is not None and not isinstance(keyword_1, (list, tuple)):
-        keyword_1 = [keyword_1]
-    if keyword_2 is not None and not isinstance(keyword_2, (list, tuple)):
-        keyword_2 = [keyword_2]
+    num_keyword_values = _get_num_keywords(file_directory, file_type, num_files)
 
-    num_keyword_1, num_keyword_2, num_kw_values = _get_num_keywords(
-        file_directory, keyword_1, keyword_2, file_type, num_files
-    )
+    (file_directory, shared_keywords, unique_keywords,
+     file_type, min_files, max_files) = _get_keywords(num_keyword_values)
 
-    file_directory, keyword_1, keyword_2, file_type, num_files = _get_keywords(
-        num_keyword_1, num_keyword_2, keyword_1, keyword_2, num_kw_values
-    )
-
-    # File finding
-    found_files = [[[] for j in range(len(keyword_2))] for i in range(len(keyword_1))]
     window_location = (None, None)
-    for j, keyword1 in enumerate(keyword_1):
-        for k, keyword2 in enumerate(keyword_2):
+    found_files = [[[] for j in range(len(unique_keywords[i]))] for i in range(len(shared_keywords))]
+
+    for i, keyword1 in enumerate(shared_keywords):
+        for j, keyword2 in enumerate(unique_keywords[i]):
             # Tries each variation of (keyword1, keyword2) and collects all files that fit
             keywords = [*keyword1, *keyword2]
             permutations = ['*'.join(p) for p in itertools.permutations(keywords) if p]
             for permutation in permutations:
                 search_term = _prepare_for_search(f'*{permutation}*.{file_type}')
-                found_files[j][k].extend(file_directory.rglob(search_term))
+                found_files[i][j].extend(file_directory.rglob(search_term))
 
             # Relaxes the search criteria and tries to find the file using only
             # one keyword if not enough files were found using the original two keywords
-            if len(found_files[j][k]) < num_files:
+            if len(found_files[i][j]) < min_files:
 
                 keywords = [*keyword1]
                 permutations = ['*'.join(p) for p in itertools.permutations(keywords)]
 
                 for permutation in permutations:
                     search_term = _prepare_for_search(f'*{permutation}*.{file_type}')
-                    found_files[j][k].extend(file_directory.rglob(search_term))
+                    found_files[i][j].extend(file_directory.rglob(search_term))
 
                 keywords = [*keyword2]
                 permutations = ['*'.join(p) for p in itertools.permutations(keywords)]
 
                 for permutation in permutations:
                     search_term = _prepare_for_search(f'*{permutation}*.{file_type}')
-                    found_files[j][k].extend(file_directory.rglob(search_term))
+                    found_files[i][j].extend(file_directory.rglob(search_term))
 
                 # Relaxes the search criteria to match any of the keywords
-                if len(found_files[j][k]) < num_files:
+                if len(found_files[i][j]) < min_files:
                     for keyword in [*keyword1, *keyword2]:
                         search_term = _prepare_for_search(f'*{keyword}*.{file_type}')
-                        found_files[j][k].extend(file_directory.rglob(search_term))
+                        found_files[i][j].extend(file_directory.rglob(search_term))
 
                     # Relaxes the search criteria to just include the file extension
                     # if not enough files have been found yet
-                    if len(found_files[j][k]) < num_files:
-                        found_files[j][k].extend(file_directory.rglob(f'*.{file_type}'))
+                    if len(found_files[i][j]) < min_files:
+                        found_files[i][j].extend(file_directory.rglob(f'*.{file_type}'))
 
                         # Relaxes the search criteria completely and includes all files in the folder
-                        if len(found_files[j][k]) < num_files:
-                            found_files[j][k].extend(file_directory.rglob('*.*'))
+                        if len(found_files[i][j]) < min_files:
+                            found_files[i][j].extend(file_directory.rglob('*.*'))
 
             # Converts the list to a set to remove duplicates and then converts back using sorted
-            found_files[j][k] = [str(file) for file in sorted(set(found_files[j][k]))]
+            found_files[i][j] = [str(file) for file in sorted(set(found_files[i][j]))]
 
-            if len(found_files[j][k]) <= num_files:
+            if len(found_files[i][j]) >= min_files and len(found_files[i][j]) <= max_files:
                 continue
             else:
                 files = [
-                    file.replace(str(file_directory), '') for file in found_files[j][k]
+                    file.replace(str(file_directory), '') for file in found_files[i][j]
                 ]
-                kw1_keywords = ', '.join(kw for kw in keyword1)
-                kw2_keywords = ', '.join(kw for kw in keyword2)
                 layout = [
                     [sg.Text('Select the file(s).')],
-                    [sg.Text((f'Current keywords:\n    Main keyword: {kw1_keywords}'
-                              f'\n    Secondary keyword: {kw2_keywords}'))],
+                    [sg.Text(('Current search term:\n'
+                              f'    "{", ".join((*keyword1, *keyword2))}"'))],
                     [sg.Listbox(key='listbox', values=files,
                                 size=(max(len(str(file)) for file in files) + 3, 8),
                                 select_mode='multiple', bind_return_key=True)],
@@ -507,13 +445,12 @@ def file_finder(file_directory=None, keyword_1=None, keyword_2=None,
                     event, values = window.read()
                     if event == sg.WIN_CLOSED:
                         safely_close_window(window)
-
-                    elif not values['listbox']:
-                        sg.popup('Please select a file.')
-
-                    elif len(values['listbox']) != num_files:
-                        sg.popup(f'Please select {num_files} file(s).')
-
+                    elif len(values['listbox']) < min_files:
+                        sg.popup(f'Please select at least {min_files} file(s).\n',
+                                 title='Error')
+                    elif len(values['listbox']) > max_files:
+                        sg.popup(f'Please select no more than {max_files} file(s).\n',
+                                 title='Error')
                     else:
                         window_location = window.current_location()
                         break
@@ -521,7 +458,7 @@ def file_finder(file_directory=None, keyword_1=None, keyword_2=None,
                 window.close()
                 window = None
 
-                found_files[j][k] = [
+                found_files[i][j] = [
                     f'{file_directory}{file}' for file in values['listbox']
                 ]
 
