@@ -2,7 +2,7 @@
 """Provides a GUI to ease the use of the peak_fitting program and save the results to Excel
 
 @author: Donald Erb
-Created on Sun May 24 15:18:18 2020
+Created on May 24, 2020
 
 """
 
@@ -38,7 +38,7 @@ def _show_fit_plot(dataframe, gui_values):
         headers = dataframe.columns
         x_index = int(gui_values['x_fit_index'])
         y_index = int(gui_values['y_fit_index'])
-        x_data = dataframe[headers[x_index]].astype(float)
+        x_data = dataframe[headers[x_index]].astype(float) #TODO should change this to .loc since could be duplicate column names
         y_data = dataframe[headers[y_index]].astype(float)
         x_min = float(gui_values['x_min']) if gui_values['x_min'] != '-inf' else -np.inf
         x_max = float(gui_values['x_max']) if gui_values['x_max'] != 'inf' else np.inf
@@ -85,62 +85,62 @@ def _show_fit_plot(dataframe, gui_values):
             if peak not in additional_peaks:
                 other_peaks = True
                 found_peaks = ax.vlines(
-                    peak, ax_y[0] - (0.01*y_diff), ax_y[1] + (0.03*y_diff),
+                    peak, ax_y[0] - (0.01 * y_diff), ax_y[1] + (0.03 * y_diff),
                     color='green', linestyle='-.', lw=2
                 )
         for peak in additional_peaks:
             user_peaks = ax.vlines(
-                peak, ax_y[0] - (0.01*y_diff), ax_y[1] + (0.03*y_diff),
+                peak, ax_y[0] - (0.01 * y_diff), ax_y[1] + (0.03 * y_diff),
                 color='blue', linestyle=':', lw=2
                 )
         ax.annotate(
-            "", (x_max, ax_y[1] + (0.03*y_diff)), (x_mid, ax_y[1] + (0.03*y_diff)),
+            "", (x_max, ax_y[1] + (0.03 * y_diff)), (x_mid, ax_y[1] + (0.03 * y_diff)),
             arrowprops=dict(width=1.2, headwidth=5, headlength=5, color='black'),
             annotation_clip=False,
         )
         ax.annotate(
-            "", (x_min, ax_y[1] + (0.03*y_diff)), (x_mid, ax_y[1] + (0.03*y_diff)),
+            "", (x_min, ax_y[1] + (0.03 * y_diff)), (x_mid, ax_y[1] + (0.03 * y_diff)),
             arrowprops=dict(width=1.2, headwidth=5, headlength=5, color='black'),
             annotation_clip=False,
         )
         ax.annotate(
-            'Fitting range', (x_mid, ax_y[1] + (0.063*y_diff)), ha='center'
+            'Fitting range', (x_mid, ax_y[1] + (0.063 * y_diff)), ha='center'
         )
         ax.vlines(
-            x_min, ax_y[0] - (0.01*y_diff), ax_y[1] + (0.03*y_diff),
+            x_min, ax_y[0] - (0.01 * y_diff), ax_y[1] + (0.03 * y_diff),
             color='black', linestyle='-', lw=2
         )
         ax.vlines(
-            x_max, ax_y[0] - (0.01*y_diff), ax_y[1] + (0.03*y_diff),
+            x_max, ax_y[0] - (0.01 * y_diff), ax_y[1] + (0.03 * y_diff),
             color='black', linestyle='-', lw=2
         )
 
         if gui_values['subtract_bkg']:
             ax.annotate(
-                "", (bkg_max, ax_y[0] - (0.01*y_diff)),
-                (bkg_mid, ax_y[0] - (0.01*y_diff)), annotation_clip=False,
+                "", (bkg_max, ax_y[0] - (0.01 * y_diff)),
+                (bkg_mid, ax_y[0] - (0.01 * y_diff)), annotation_clip=False,
                 arrowprops=dict(width=1.2, headwidth=5, headlength=5, color='red')
             )
             ax.annotate(
-                "", (bkg_min, ax_y[0] - (0.01*y_diff)),
-                (bkg_mid, ax_y[0] - (0.01*y_diff)),
+                "", (bkg_min, ax_y[0] - (0.01 * y_diff)),
+                (bkg_mid, ax_y[0] - (0.01 * y_diff)),
                 arrowprops=dict(width=1.2, headwidth=5, headlength=5, color='red'),
                 annotation_clip=False
             )
             ax.annotate(
-                'Background range', (bkg_mid, ax_y[0] - (0.085*y_diff)),
+                'Background range', (bkg_mid, ax_y[0] - (0.085 * y_diff)),
                 color='red', ha='center'
             )
             ax.vlines(
-                bkg_min, ax_y[0] - (0.01*y_diff), ax_y[1] + (0.03*y_diff),
+                bkg_min, ax_y[0] - (0.01 * y_diff), ax_y[1] + (0.03 * y_diff),
                 color='red',linestyle='--', lw=2
             )
             ax.vlines(
-                bkg_max, ax_y[0] - (0.01*y_diff), ax_y[1] + (0.03*y_diff),
+                bkg_max, ax_y[0] - (0.01 * y_diff), ax_y[1] + (0.03 * y_diff),
                 color='red', linestyle='--', lw=2
             )
 
-        ax.set_ylim(ax_y[0] - (0.15*y_diff), ax_y[1] + (0.15*y_diff))
+        ax.set_ylim(ax_y[0] - (0.15 * y_diff), ax_y[1] + (0.15 * y_diff))
 
         peak_list = []
         if (additional_peaks.size > 0) and (other_peaks):
@@ -254,7 +254,7 @@ def fit_dataframe(dataframe, user_inputs=None):
         values = default_inputs
 
     else:
-        available_models = [*peak_fitting.peak_transformer().keys()]
+        available_models = list(peak_fitting.peak_transformer().keys())
 
         if (('Voigt' in default_inputs['model_list']) or
             ('VoigtModel' == default_inputs['default_model'])) :
@@ -1118,13 +1118,14 @@ def launch_peak_fitting_gui(dataframe=None, gui_values=None, excel_writer=None,
         writer = excel_writer
     else:
         layout = [
-            [sg.Text('Select filename for peak fitting')],
+            [sg.Text('File name for peak fitting results')],
             [sg.Input('', key='file', size=(20, 1),
                       disabled=True, text_color='black'),
             sg.FileSaveAs(file_types=(("Excel Workbook (xlsx)", "*.xlsx"),),
                           key='browse', target='file')],
             [sg.Text('')],
-            [sg.Button('Submit', bind_return_key=True,
+            [sg.Button('Skip Saving'),
+             sg.Button('Submit', bind_return_key=True,
                        button_color=utils.PROCEED_COLOR),
              sg.Check('New File', key='new_file')]
         ]
@@ -1134,7 +1135,10 @@ def launch_peak_fitting_gui(dataframe=None, gui_values=None, excel_writer=None,
             event, values = window.read()
             if event == sg.WIN_CLOSED:
                 utils.safely_close_window(window)
-
+            elif event == 'Skip Saving':
+                save_excel = False
+                writer = None
+                break
             elif event == 'Submit':
                 if utils.validate_inputs(values, strings=[['file', 'Excel file']]):
                     break
@@ -1142,16 +1146,17 @@ def launch_peak_fitting_gui(dataframe=None, gui_values=None, excel_writer=None,
         window.close()
         del window
 
-        file_path = Path(values['file'])
-        if not file_path.suffix.lower() or file_path.suffix.lower() != '.xlsx':
-            values['file'] = str(Path(file_path.parent, file_path.stem + '.xlsx'))
+        if save_excel:
+            file_path = Path(values['file'])
+            if not file_path.suffix.lower() or file_path.suffix.lower() != '.xlsx':
+                values['file'] = str(Path(file_path.parent, file_path.stem + '.xlsx'))
 
-        if not values['new_file'] and Path(values['file']).exists():
-            mode = 'a'
-        else:
-            mode = 'w'
+            if not values['new_file'] and Path(values['file']).exists():
+                mode = 'a'
+            else:
+                mode = 'w'
 
-        writer = pd.ExcelWriter(values['file'], engine='openpyxl', mode=mode)
+            writer = pd.ExcelWriter(values['file'], engine='openpyxl', mode=mode)
 
     # Formatting styles for the Excel workbook
     for style, kwargs in utils.DEFAULT_FITTING_FORMATS.items():
@@ -1166,7 +1171,7 @@ def launch_peak_fitting_gui(dataframe=None, gui_values=None, excel_writer=None,
     proceed = True
     for dataframe in fit_dataframes:
         try:
-            with plt.rc_context(rc_params): #TODO check if this closes the figure as soon as fitting is done?
+            with plt.rc_context(rc_params):
                 fit_output = fit_dataframe(dataframe, gui_values)
 
         except (utils.WindowCloseError, KeyboardInterrupt):
